tlslite.utils.AES.AES

Package tlslite :: Package utils :: Module AES :: Class AES |
[show private | hide private]
[frames | no frames]

## Class AES

Known Subclasses:
  `Cryptlib_AES`, `OpenSSL_AES`, `PyCrypto_AES`, `Python_AES`

Method Summary
| `__init__(self, key, mode, IV, implementation)`
| `decrypt(self, ciphertext)`
| `encrypt(self, plaintext)`

Generated by Epydoc 2.0 on Mon Feb 21 21:56:55 2005 | http://epydoc.sf.net